import { InputWrapper, SelectWrapper } from "@/components/fields/Fields";
import FormComponent from "@/components/form/Form";
import { BadgeColorKey, badgeColors } from "@/utils/constant";
import prepareValidationSchema from "@/utils/validation-schema";
import { Button, FormControl, FormLabel, Modal, ModalBody, ModalCloseButton, ModalContent, ModalFooter, ModalHeader, ModalOverlay, Text, useColorModeValue } from "@chakra-ui/react";
import { useRef } from "react";
import { AssignPriorityInterface } from "../type/ibc";
import { formFields } from "../variables/formFields";

interface AssignPriorityFormProps {
    isOpen: boolean;
    onClose: () => void;
    currentUser: AssignPriorityInterface | null;
    handleSubmit: (values: FormData) => Promise<void>;
}



const IbcModalForm: React.FC<AssignPriorityFormProps> = ({ isOpen, onClose, currentUser, handleSubmit }) => {
    const formRef = useRef(null);
    const textColor = useColorModeValue("navy.700", "white");
    const brandStars = useColorModeValue("brand.500", "brand.400");

    const formDetails = prepareValidationSchema(formFields);
    const { initialFormData, validationSchema } = formDetails;

    // Set initial values based on whether we are adding or editing
    const initialValues = currentUser ? { ...currentUser } : initialFormData;

    const handleSubmitClick = () => {
        formRef?.current?.externalHandleSubmit();
    };

    return (
        <Modal onClose={onClose} size="lg" isOpen={isOpen}>
            <ModalOverlay />
            <ModalContent>
                <ModalHeader>{currentUser ? "Edit" : "Create"} Assignment Priority</ModalHeader>
                <ModalCloseButton />
                <ModalBody>
                    <FormComponent
                        ref={formRef}
                        validationSchema={validationSchema}
                        initialValues={initialValues}
                        // enableReinitialize // Ensures the form reinitializes with updated initial values
                        submitForm={handleSubmit}
                    >
                        <FormControl w="full">
                            <FormLabel fontSize="sm" fontWeight="500" color={textColor} mb="8px">
                                Name
                                <Text color={brandStars}>*</Text>
                            </FormLabel>
                            <InputWrapper
                                form
                                fieldName="name"
                                defaultValue={currentUser?.name}
                                id="name"
                                variant="auth"
                                w="full"
                                mb="2px"
                                fontSize="sm"
                                type="text"
                                fontWeight="500"
                            />
                        </FormControl>
                        <FormControl w="full">
                            <FormLabel fontSize="sm" fontWeight="500" color={textColor} mb="8px">
                                Color
                                <Text color={brandStars}>*</Text>
                            </FormLabel>
                            <SelectWrapper
                                form
                                fieldName="color"
                                defaultValue={currentUser?.color}
                                id="color"
                                variant="auth"
                                w="full"
                                mb="2px"
                                fontSize="sm"
                                fontWeight="500"
                                options={Object?.keys(badgeColors)?.map((colorKey) => {
                                    const color = colorKey as BadgeColorKey;
                                    return {
                                        label: color.charAt(0).toUpperCase() + color.slice(1),
                                        value: color,
                                    };
                                })}
                            />
                        </FormControl>
                    </FormComponent>
                </ModalBody>
                <ModalFooter>
                    <Button variant="brand" onClick={handleSubmitClick} mr={3}>
                        {currentUser ? "Save" : "Create"}
                    </Button>
                    <Button onClick={onClose}>Cancel</Button>
                </ModalFooter>
            </ModalContent>
        </Modal>
    );
};

export default IbcModalForm;
